@@ -7,7 +7,7 @@
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 package Nile::Plugin::Memcached;
 
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 our $AUTHORITY = 'cpan:MEWSOFT';
 
 =pod
@@ -39,7 +39,7 @@ Nile::Plugin::Memcached - Memcached client plugin for the Nile framework.
     
 Nile::Plugin::Memcached - Memcached client plugin for the Nile framework.
 
-This is a client for the memcached protocol using L<Memcached::Client> module. All methods of the L<Memcached::Client> module are supported.
+Returns L<Memcached::Client> object. All methods of L<Memcached::Client> are supported.
 
 Plugin settings in th config file under C<plugin> section.
 
@@ -56,33 +56,15 @@ Plugin settings in th config file under C<plugin> section.
 
 use Nile::Plugin;
 use Memcached::Client;
-#~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-has 'client' => (
-      is      => 'rw',
-      lazy  => 1,
-      isa  => "Memcached::Client",
-      default => undef,
-      handles => [qw(
-                    log compress_threshold namespace hash_namespace set_preprocessor set_servers
-                    connect disconnect add add_multi append append_multi decr decr_multi delete
-                    delete_multi flush_all get get_multi incr incr_multi prepend prepend_multi
-                    remove replace replace_multi set set_multi stats version
-                   )],
-  );
-
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 sub main {
-
     my ($self, $arg) = @_;
-    
     my $app = $self->app;
     my $setting = $self->setting();
-
 	if (defined($setting->{servers}) && (ref($setting->{servers}) ne "ARRAY")) {
 		$setting->{servers} = [$setting->{servers}];
 	}
-
-    $self->client(Memcached::Client->new($setting));
+    rebless => Memcached::Client->new($setting);
 }
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
